"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _RoomExtended_instances, _RoomExtended_config, _RoomExtended_resolveOrNotify, _RoomExtended_emmitAction;
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoomExtended = void 0;
const uuid_1 = require("uuid");
const room_1 = require("./room");
const promises_1 = __importDefault(require("./promises"));
const constants_1 = require("./constants");
class RoomExtended extends room_1.Room {
    constructor(connection, id, name, pin, nickname, creationTime, config) {
        super(connection, name, pin, nickname, creationTime);
        _RoomExtended_instances.add(this);
        _RoomExtended_config.set(this, void 0);
        this._id = id;
        if (!config.participantsConfig) {
            config.participantsConfig = {};
        }
        __classPrivateFieldSet(this, _RoomExtended_config, config, "f");
    }
    config() {
        return __classPrivateFieldGet(this, _RoomExtended_config, "f");
    }
    createRoom() {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.CREATE_ROOM, {
                name: self._name,
                pin: self._pin,
                internalMessageId: id
            });
        });
    }
    ;
    sendControlMessage(msg, broadcast, to) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.SEND_CONTROL_MESSAGE, {
                roomId: self._id,
                broadcast: broadcast,
                from: "",
                to: to,
                body: msg,
                internalMessageId: id
            });
        });
    }
    ;
    authorizeWaitingList(userId, authorized) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.AUTHORIZE_WAITING_LIST, {
                id: self._id,
                userId: userId,
                authorized: authorized,
                internalMessageId: id
            });
        });
    }
    ;
    moveToWaitingRoom(nickname) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.MOVE_TO_WAITING_ROOM, {
                roomId: self._id,
                nickname: nickname,
                internalMessageId: id
            });
        });
    }
    ;
    configureWaitingRoom(enabled) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.CONFIGURE_WAITING_ROOM, {
                id: self._id,
                enabled: enabled,
                internalMessageId: id
            });
        });
    }
    ;
    assignRole(nickname, role) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.ASSIGN_ROLE, {
                roomId: self._id,
                nickname: nickname,
                role: role,
                internalMessageId: id
            });
        });
    }
    ;
    reclaimOwnerRights() {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.RECLAIM_OWNER_RIGHTS, {
                roomId: self._id,
                internalMessageId: id
            });
        });
    }
    ;
    subscribeToWaitingParticipant(nickname) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.SUBSCRIBE_TO_WAITING_PARTICIPANT, {
                roomId: self._id,
                nickname: nickname,
                internalMessageId: id
            });
        });
    }
    ;
    unsubscribeFromWaitingParticipant(nickname) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.UNSUBSCRIBE_FROM_WAITING_PARTICIPANT, {
                roomId: self._id,
                nickname: nickname,
                internalMessageId: id
            });
        });
    }
    ;
    setLock(locked) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_LOCK, { id: self._id, value: locked }, resolve, reject);
        });
    }
    ;
    setInitialAudioMuted(muted) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_INITIAL_AUDIO_MUTED, { id: self._id, value: muted }, resolve, reject);
        });
    }
    ;
    setInitialVideoMuted(muted) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_INITIAL_VIDEO_MUTED, { id: self._id, value: muted }, resolve, reject);
        });
    }
    ;
    setInitialScreenSharingMuted(muted) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_INITIAL_SCREEN_SHARING_MUTED, { id: self._id, value: muted }, resolve, reject);
        });
    }
    ;
    setAudioMuted(muted) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_AUDIO_MUTED, { id: self._id, value: muted }, resolve, reject);
        });
    }
    ;
    setVideoMuted(muted) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_VIDEO_MUTED, { id: self._id, value: muted }, resolve, reject);
        });
    }
    ;
    setScreenSharingMuted(muted) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_SCREEN_SHARING_MUTED, { id: self._id, value: muted }, resolve, reject);
        });
    }
    ;
    setChatMuted(muted) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_CHAT_MUTED, { id: self._id, value: muted }, resolve, reject);
        });
    }
    ;
    setCanChangeNickname(canChange) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_CAN_CHANGE_NICKNAME, { id: self._id, value: canChange }, resolve, reject);
        });
    }
    ;
    setScreenSharingMultipleShares(multipleShares) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_SCREEN_SHARING_MULTIPLE_SHARES, { id: self._id, value: multipleShares }, resolve, reject);
        });
    }
    ;
    setScreenSharingEveryoneCanShare(everyoneCanShare) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_SCREEN_SHARING_EVERYONE_CAN_SHARE, { id: self._id, value: everyoneCanShare }, resolve, reject);
        });
    }
    ;
    setScreenSharingEveryoneCanDoSubsequentShare(canDoSubsequentShare) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_ROOM_SCREEN_SHARING_EVERYONE_CAN_DO_SUBSEQUENT_SHARE, { id: self._id, value: canDoSubsequentShare }, resolve, reject);
        });
    }
    ;
    setParticipantAudioMuted(nickname, muted) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_PARTICIPANT_AUDIO_MUTED, { id: self._id, value: muted, nickname: nickname }, resolve, reject);
        });
    }
    ;
    setParticipantVideoMuted(nickname, muted) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_PARTICIPANT_VIDEO_MUTED, { id: self._id, value: muted, nickname: nickname }, resolve, reject);
        });
    }
    ;
    setParticipantScreenSharingMuted(nickname, muted) {
        const self = this;
        return new Promise((resolve, reject) => {
            __classPrivateFieldGet(self, _RoomExtended_instances, "m", _RoomExtended_emmitAction).call(self, constants_1.InternalApi.SET_PARTICIPANT_SCREEN_SHARING_MUTED, { id: self._id, value: muted, nickname: nickname }, resolve, reject);
        });
    }
    ;
    processEvent(e) {
        const _super = Object.create(null, {
            processEvent: { get: () => super.processEvent }
        });
        return __awaiter(this, void 0, void 0, function* () {
            if (e.type === constants_1.RoomEvent.ROOM_LOCKED) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").locked = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.ROOM_INITIAL_AUDIO_MUTED) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").initialAudioMuted = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.ROOM_INITIAL_VIDEO_MUTED) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").initialVideoMuted = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.ROOM_INITIAL_SCREEN_SHARING_MUTED) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").initialScreenSharingMuted = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.ROOM_AUDIO_MUTED) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").audioMuted = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.ROOM_VIDEO_MUTED) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").videoMuted = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.ROOM_SCREEN_SHARING_MUTED) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").screenSharingMuted = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.ROOM_CHAT_MUTED) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").chatMuted = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.ROOM_CAN_CHANGE_NICKNAME) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").canChangeNickname = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.ROOM_SCREEN_SHARING_MULTIPLE_SHARES) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").screenSharingConfig.multipleShares = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.ROOM_SCREEN_SHARING_EVERYONE_CAN_SHARE) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").screenSharingConfig.everyoneCanShare = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.ROOM_SCREEN_SHARING_EVERYONE_CAN_DO_SUBSEQUENT_SHARE) {
                const value = e.value;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").screenSharingConfig.everyoneCanDoSubsequentShare = value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, value);
            }
            else if (e.type === constants_1.RoomEvent.PARTICIPANT_CONFIG) {
                const pConfig = e;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").participantsConfig[pConfig.nickname] = pConfig.config;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, e);
            }
            else if (e.type === constants_1.RoomEvent.PARTICIPANT_AUDIO_MUTED) {
                const mutedEvent = e;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").participantsConfig[mutedEvent.nickname].audioMuted = mutedEvent.value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, mutedEvent.value);
            }
            else if (e.type === constants_1.RoomEvent.PARTICIPANT_VIDEO_MUTED) {
                const mutedEvent = e;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").participantsConfig[mutedEvent.nickname].videoMuted = mutedEvent.value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, mutedEvent.value);
            }
            else if (e.type === constants_1.RoomEvent.PARTICIPANT_SCREEN_SHARING_MUTED) {
                const mutedEvent = e;
                __classPrivateFieldGet(this, _RoomExtended_config, "f").participantsConfig[mutedEvent.nickname].screenSharingMuted = mutedEvent.value;
                __classPrivateFieldGet(this, _RoomExtended_instances, "m", _RoomExtended_resolveOrNotify).call(this, e, e.type, mutedEvent.value);
            }
            else {
                _super.processEvent.call(this, e);
            }
        });
    }
}
exports.RoomExtended = RoomExtended;
_RoomExtended_config = new WeakMap(), _RoomExtended_instances = new WeakSet(), _RoomExtended_resolveOrNotify = function _RoomExtended_resolveOrNotify(e, type, value) {
    if (!promises_1.default.resolve(e.internalMessageId, value)) {
        this.notifier.notify(type, e);
    }
}, _RoomExtended_emmitAction = function _RoomExtended_emmitAction(action, data, resolve, reject) {
    const id = (0, uuid_1.v4)();
    promises_1.default.add(id, resolve, reject);
    this.connection.send(action, Object.assign(Object.assign({}, data), { internalMessageId: id }));
};
//# sourceMappingURL=room-extended.js.map